// some things are automatically loaded in every rust program
// https://doc.rust-lang.org/std/prelude/index.html
// for extras, import them with `use`:
use std::io;
use std::cmp::Ordering;
use rand::Rng;

fn main() {
    println!("Guess the number!");
    println!("input your guess");
    // ..= is inclusive
    let secret_number = rand::thread_rng().gen_range(1..=100);
    println!("The secret number is: {secret_number}");
    // vars are immutable by default, change this
    // The :: syntax in the ::new line indicates that new is an _associated function_ of the String
    //         a function that’s implemented on a type
    // could still call this without importing it via std::io::stdin
    // this can be one line, it is broken up for readability.
    loop {
        let mut guess = String::new();
        io::stdin()
            // & indicates that this argument is a reference,
            // references are also immutable by default so &mut is needed
            .read_line(&mut guess)
            // expect handles the Err variant by crashing the program. There are other ways to handle
            // errors.
            .expect("Failed to read line");
        // read_line returns a `result` value. result is an enum. Each possible state is a variant.
        // Result's variants are Ok and Err

        // shadowing V
        // change from expect which crashes all the time to match
        // to perform an action depending on the value of the enum
        let guess: u32 = match guess.trim().parse() {
            Ok(num) => num,
            Err(_) => {
                println!("that aint no number I ever heard of");
                continue;
            }
        };
        // trim removes space and \n
        // single colon is type annotation
        //
        println!("you guessed: {guess}");
        // a match expression is made of arms. an arm is a pattern to match and code to run against it.
        // switch/case
        match guess.cmp(&secret_number) {
            Ordering::Less => println!("too small"),
            Ordering::Greater => println!("too big"),
            Ordering::Equal => {
                println!("you win");
                break;
            }
        }
    }
}
// cargo doc --open
// generate doc about this code and dependancies
